@@ -27,8 +27,8 @@ describe 'nova' do
         :refreshonly => true
       )}
 
-      it 'configures glance api servers' do
-        is_expected.to contain_nova_config('glance/api_servers').with_value('http://localhost:9292')
+      it 'does not configure glance api servers' do
+        is_expected.to_not contain_nova_config('glance/api_servers')
       end
 
       it 'does not configure auth_strategy' do
@@ -61,6 +61,8 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(false)
         is_expected.to contain_nova_config('DEFAULT/cert').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/key').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('console/ssl_ciphers').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('console/ssl_minimum_version').with_value('<SERVICE DEFAULT>')
       end
 
       it 'configures block_device_allocate params' do
@@ -73,7 +75,8 @@ describe 'nova' do
 
       let :params do
         {
-          :glance_api_servers                      => 'http://localhost:9292',
+          :glance_endpoint_override                => 'http://localhost:9292',
+          :glance_api_servers                      => ['http://localhost:9292', 'http://localhost:9293'],
           :default_transport_url                   => 'rabbit://rabbit_user:password@localhost:5673',
           :rpc_response_timeout                    => '30',
           :control_exchange                        => 'nova',
@@ -109,6 +112,8 @@ describe 'nova' do
           :ssl_only                                => true,
           :cert                                    => '/etc/ssl/private/snakeoil.pem',
           :key                                     => '/etc/ssl/certs/snakeoil.pem',
+          :console_ssl_ciphers                     => 'kEECDH+aECDSA+AES:kEECDH+AES+aRSA:kEDH+aRSA+AES',
+          :console_ssl_minimum_version             => 'tlsv1_2',
         }
       end
 
@@ -123,8 +128,12 @@ describe 'nova' do
         })
       end
 
+      it 'configures glance endpoint_override' do
+        is_expected.to contain_nova_config('glance/endpoint_override').with_value('http://localhost:9292')
+      end
+
       it 'configures glance api servers' do
-        is_expected.to contain_nova_config('glance/api_servers')
+        is_expected.to contain_nova_config('glance/api_servers').with_value(['http://localhost:9292', 'http://localhost:9293'])
       end
 
       it 'configures auth_strategy' do
@@ -175,6 +184,8 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(true)
         is_expected.to contain_nova_config('DEFAULT/cert').with_value('/etc/ssl/private/snakeoil.pem')
         is_expected.to contain_nova_config('DEFAULT/key').with_value('/etc/ssl/certs/snakeoil.pem')
+        is_expected.to contain_nova_config('console/ssl_ciphers').with_value('kEECDH+aECDSA+AES:kEECDH+AES+aRSA:kEDH+aRSA+AES')
+        is_expected.to contain_nova_config('console/ssl_minimum_version').with_value('tlsv1_2')
       end
 
       context 'with multiple notification_driver' do
